@@ -47,9 +47,11 @@ from awkward.generate import fromiter, fromiterchunks
 
 from awkward.persist import serialize, deserialize, save, load, hdf5
 
+from awkward.arrow import toarrow, fromarrow, toparquet, fromparquet
+
 # convenient access to the version number
 from awkward.version import __version__
 
-__all__ = ["numpy", "ChunkedArray", "AppendableArray", "IndexedArray", "SparseArray", "JaggedArray", "MaskedArray", "BitMaskedArray", "IndexedMaskedArray", "Methods", "ObjectArray", "Table", "UnionArray", "VirtualArray", "StringArray", "fromiter", "fromiterchunks", "serialize", "deserialize", "save", "load", "hdf5", "__version__"]
+__all__ = ["numpy", "ChunkedArray", "AppendableArray", "IndexedArray", "SparseArray", "JaggedArray", "MaskedArray", "BitMaskedArray", "IndexedMaskedArray", "Methods", "ObjectArray", "Table", "UnionArray", "VirtualArray", "StringArray", "fromiter", "fromiterchunks", "serialize", "deserialize", "save", "load", "hdf5", "toarrow", "fromarrow", "toparquet", "fromparquet", "__version__"]
 
 __path__ = __import__("pkgutil").extend_path(__path__, __name__)
